/*                                                                                 
 *  pref.c: Preferences
 *
 *  Copyright (C) 2010- John Coppens (john@jcoppens.com)        
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 3 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *  
 *  You should have received a copy of the GNU Library General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <confmgr3.h>

#include "support.h"
#include "main.h"
#include "pref.h"

preferences pref;

conf_definition preftable[] = {
  // History
  {"pref_hist_allowdups_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "history/allow_dups",		&pref.allowdups,		"0"},
  {"pref_hist_update_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "history/update",			&pref.updatehist,		"0"},
  {"pref_hist_recorderrors_cbtn",	NULL,	CDEF_CBTN2CHAR,		0,
   "history/recorderrors",		&pref.recorderrors,		"0"},
  {"pref_hist_limit_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "history/limit",			&pref.limit,			"0"},
  {"pref_hist_limitlength_spbtn",	NULL, CDEF_SPBTN2INT,		0,
   "history/limitlength",		&pref.limitlength,		"100"},

  // General settings
  {"pref_gen_mode_cbbox",		NULL,	CDEF_CBBOX2INT,		0,
   "general/mode",			&pref.gen_mode,			"2"},
  {"pref_gen_precisionguard_cbtn",	NULL,	CDEF_CBTN2CHAR,		0,
   "general/precisionguard",		&pref.gen_guard,		"0"},
  {"pref_gen_stayontop_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "general/stayontop",			&pref.gen_stayontop,		"1"},
  {"pref_gen_showmenu_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "general/showmenu",			&pref.gen_showmenu,		"1"},
  {"pref_gen_showborders_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "general/showborders",			&pref.gen_showborders,		"1"},
  {"pref_gen_liveprecision_cbtn",	NULL,	CDEF_CBTN2CHAR,		0,
   "general/liveprecision",		&pref.gen_liveprec,		"0"},
  {"pref_gen_decsep_entry",		NULL,	CDEF_ENTRY2STR,		0,
   "general/decsep",			&pref.gen_decsep,		""},
  {"pref_gen_1000sep_entry",		NULL,	CDEF_ENTRY2STR,		0,
   "general/1000sep",			&pref.gen_1000sep,		""},

  {"pref_gen_inernalprec_spbtn",	NULL,	CDEF_SPBTN2INT,		0,
   "general/internalprec",		&pref.gen_intprecision,		"1024"},
  {"pref_dsp_maxprec_spbtn",		NULL,	CDEF_SPBTN2INT,		0,
   "display/maxprecision",		&pref.dsp_maxprecision,		"150"},

  // Answer display
  {"pref_dsp_dec_rbtn",			NULL,	CDEF_RBTN2CHAR,		0,
   "display/mode_dec",			&pref.dsp_mode,			"1"},
  {"pref_dsp_hex_rbtn",			NULL,	CDEF_RBTN2CHAR,		0,
   "display/mode_hex",			&pref.dsp_mode,			"0"},
  {"pref_dsp_oct_rbtn",			NULL,	CDEF_RBTN2CHAR,		0,
   "display/mode_oct",			&pref.dsp_mode,			"0"},
  {"pref_dsp_bin_rbtn",			NULL,	CDEF_RBTN2CHAR,		0,
   "display/mode_bin",			&pref.dsp_mode,			"0"},
  {"pref_dsp_prefix_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "display/prefixes",			&pref.dsp_prefixes,		"0"},
  {"pref_dsp_wholeints_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "display/wholeintegers",		&pref.dsp_wholeints,		"0"},
  {"pref_dsp_delim_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "display/delimiters",		&pref.dsp_delimiters,		"0"},
  {"pref_dsp_engineering_cbbox",	NULL,	CDEF_CBBOX2STR,		0,
   "display/engineering",		&pref.dsp_engineering,		"auto"},
  {"pref_dsp_rounding_cbbox",		NULL,	CDEF_CBBOX2STR,		0,
   "display/rounding",			&pref.dsp_rounding,		"none"},


  // Parsing expressions
  {"pref_exp_parseundef_ctbn",		NULL,	CDEF_CBTN2CHAR,		0,
   "expressions/parseundefined",	&pref.exp_parseundef,		"1"},
  {"pref_exp_useradians_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "expressions/useradians",		&pref.exp_useradians,		"0"},
  {"pref_gen_cstylemod_cbtn",		NULL,	CDEF_CBTN2CHAR,		0,
   "general/cstylemod",			&pref.gen_cmod,			"1"},

  // Fonts
  {"pref_font_form_fontbtn",		NULL,	CDEF_FONTBTN2STR,	0,
   "font/formula",			&pref.font_formula,		"Monospace 10"},
  {"pref_font_result_fontbtn",		NULL,	CDEF_FONTBTN2STR,	0,
   "font/result",			&pref.font_result,		"Monospace bold 12"},

  {NULL}
};

void
load_preferences(void)
{
  load_by_table(preftable, CONF_PATH);
}

void
save_preferences(void)
{
  save_by_table(preftable, CONF_PATH);
}

void
parse_preferences(void)
{
  confd_get_values_from_widgets(preftable);
}

void
show_preferences(void)
{
  confd_set_glade2_widgets(preftable, PrefWindow, lookup_widget);
  confd_set_widgets_to_values(preftable);
}
